==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/default/xt2arffHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "xmlTableWEKAѥǡ(arffեޥå)ؤѴ"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-n*/
#define NUMT "͹̾ꥹ"
#define NUMC "͹"
#define NUMF NULL

/*-d*/
#define CATT "ƥ̾ꥹ"
#define CATC "ƥ"
#define CATF NULL

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "xmlTableWEKAѤΥǡեޥå(arff)Ѵ롣arffǤϡ°ηꤹɬפꡢ-d-nǥƥ귿ܤȿͷܤ򤽤줾ꤹ롣stringշˤϸߤΤȤбƤʤ"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xt2arff -n , -d ֹܵ, -i dat.xt -o rsl.arff\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xt2txt,txt2xt,xt2xml,xml2xt"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4.tar.gz: musashi-core-1.0.4/help/default/xt2arffHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "xmlTableWEKAѥǡ(arffեޥå)ؤѴ"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-n*/
#define NUMT "͹̾ꥹ"
#define NUMC "͹"
#define NUMF NULL

/*-d*/
#define CATT "ƥ̾ꥹ"
#define CATC "ƥ"
#define CATF NULL

/*-s*/
#define STRT "ʸ̾ꥹ"
#define STRC "ʸ"
#define STRF NULL

/*-D*/
#define DATT "()̾ꥹ"
#define DATC "()"
#define DATF "ޤ"


/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "xmlTableWEKAѤΥǡեޥå(arff)Ѵ롣arffǤϡ°ηꤹɬפꡢ-dǥƥ귿ܤ-nǿͷܤ-sʸ󷿹ܤ-Dշܤ򤽤줾ꤹ롣շ̾%tդлޤͤȸʤդʤդΤߤͤȸʤ%tդͤxtcalcatؿդȻ礷Ĺ14ʸ(yyyyymmddhhmmss)ѴƤɬפ롣"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xt2arff -n , -d ֹܵ, -i dat.xt -o rsl.arff\n\
xt2arff -s ID -n , -D ,Ź%t -i dat.xt -o rsl.arff\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xt2txt,txt2xt,xt2xml,xml2xt"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
